@@ -280,7 +280,7 @@ class hdimage(object):
                 res.ctx.change_password(str(''))
             if struct['non_standard'] or struct['standard']:
                 for nsc in struct['non_standard']:
-                    certdata = zf.read(nsc)
+                    certdata = cryptoapi.autopem(zf.read(nsc))
                     res.certs['AT_KEYEXCHANGE'] = _cert_info(certdata)
                     newc = csp.Cert(certdata)
                     newc.bind(res.ctx, csp.AT_KEYEXCHANGE)
@@ -289,7 +289,7 @@ class hdimage(object):
                     key = res.ctx.get_key(csp.AT_KEYEXCHANGE)
                     key.store_cert(newc)
                 for nsc in struct['standard']:
-                    certdata = zf.read(nsc + '.cer')
+                    certdata = cryptoapi.autopem(zf.read(nsc + '.cer'))
                     res.certs[nsc] = _cert_info(certdata)
                     newc = csp.Cert(certdata)
                     keyspec = getattr(csp, nsc)
@@ -343,9 +343,9 @@ class hdimage(object):
         res['certs'] = {}
 
         for nsc in struct['non_standard']:
-            certdata = zf.read(nsc)
+            certdata = cryptoapi.autopem(zf.read(nsc))
             res['certs']['AT_KEYEXCHANGE'] = _cert_info(certdata)
         for nsc in struct['standard']:
-            certdata = zf.read(nsc + '.cer')
+            certdata = cryptoapi.autopem(zf.read(nsc + '.cer'))
             res['certs'][nsc] = _cert_info(certdata)
         return res
